@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 14/01/2023
+#Date last Update : 14/10/2023
 
 import vmpsys as sys
 
@@ -33,7 +33,7 @@ webpage_="http://www.ragnu.it"
 license_="GPL3"
 
 ##Vampiria version
-version_="0.4.2"
+version_="0.5.1"
 
 ##Vampiria release type
 release_="alpha"
@@ -173,7 +173,7 @@ gpkg_="pkg/"
 python_=sys.executable()
 
 ##Version less python version for installer
-pyversion_=(3,9)
+pyversion_=(3,11)
 
 ##Python library directory src files<BR>
 #
@@ -235,7 +235,8 @@ cpp_help_=['g++','--help']
 ##Compiler command<BR>
 #
 #@param included compiler included path(source framework already inserted by default)<BR>
-#@param options  compiler option list
+#@param options  compiler option list<BR>
+#
 #@return cpp compiler string
 def cpp_(included,options):
   cpp="g++ -ggdb -Wall -fPIC -I {0}".format(sys.path(fwsrc_))
@@ -295,6 +296,8 @@ configlist_= ["/*Config file autogenerate from install*/",
               "#define VMODULES            \"{0}\"".format(sys.path(gmodules_)),
               "#define VMODMAIN            \"{0}\"".format(gmodulemain_),
               "#define VMANIFEST           \"{0}\"".format(gmodulemanifest_),
+              "#define VPKG                \"{0}\"".format(sys.path(gpkg_)),
+              "#define VVPKG               \"{0}\"".format(sys.path(gvpkg_)),
               "#define FDTD                \"{0}\"".format(sys.path(fwdtd_)),
               "#define VPYTHON             \"{0}\"".format(python_),
               "#define VPYENV              \"{0}\"".format(sys.path(gpyenv_)),
