@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 14/07/2021
+#Date last Update : 09/10/2023
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -123,16 +123,16 @@ def clear():
 
 vmplib=clib()
 vmplib.name='vmp'
-vmplib.hdr=['assert.h','dirent.h','errno.h','fcntl.h','pthread.h','pty.h','signal.h','sys/time.h','sys/stat.h','sys/types.h','sys/wait.h','sys/ioctl.h','net/if.h','string.h','strings.h','stdarg.h','stdio.h','stdlib.h','time.h','unistd.h']
+vmplib.hdr=['assert.h','dirent.h','errno.h','fcntl.h','ctype.h','pthread.h','pty.h','signal.h','sys/time.h','sys/stat.h','sys/types.h','sys/wait.h','sys/ioctl.h','net/if.h','string.h','strings.h','stdarg.h','stdio.h','stdlib.h','time.h','unistd.h']
 vmplib.files=[('./',['args','basetypes','buf','env','error','io','lib','math','signal','thread','time','unicode','utils'])]
-vmplib.loptions=['-pthread','-lutil']
+vmplib.loptions=['-pthread','-lutil','-lc']
 vmplib.config=True
 clibs_[vmplib.name]=vmplib
 
 pylib=clib()
 pylib.name='pylib'
 pylib.files=[('./',['args','lib','module','stub']),('lib/',['arg_from_python','class_impl','converter','def','pybase'])]
-pylib.libs=[('python3','3.9')]
+pylib.libs=[('python3','3.11')]
 pylib.coptions=['`pkg-config --cflags python3`']
 pylib.loptions=['`pkg-config --libs python3`']
 pylib.dependencies=['vmp']
@@ -181,8 +181,8 @@ clibs_[moduleslib.name]=moduleslib
 jsonlib=clib()
 jsonlib.name='json'
 jsonlib.dependencies=['vmp','net','packet']
-jsonlib.files=[('./',['json','japi','jdata','jtable','jlist'])]
-jsonlib.libs=[('json-c','0.15')]
+jsonlib.files=[('./',['json','japi','jdata','jtable','jlist','jrp'])]
+jsonlib.libs=[('json-c','0.16')]
 jsonlib.loptions=['`pkg-config json-c --cflags --libs`']
 clibs_[jsonlib.name]=jsonlib
 
