@@ -113,7 +113,7 @@ event=pylib()
 event.name="vmp_event"
 event.dependencies=[]
 event.cbuild()
-event.setup.files=[('./',['event_','inputui_','simplexui_','threadui_','timerui_'])]
+event.setup.files=[('./',['event_','inputui_','processui_','simplexui_','timerui_'])]
 event.setup.dependencies=['pylib','event','vmp']
 pylibs_[event.name]=event
 
@@ -146,7 +146,7 @@ pylibs_[plugin.name]=plugin
 json=pylib()
 json.name='vmp_json'
 json.cbuild()
-json.setup.files=[('./',['json_','jdata_','jlist_','jtable_','japi_'])]
+json.setup.files=[('./',['json_','jdata_','jlist_','jtable_','japi_','jrp_'])]
 json.setup.dependencies=['vmp','pylib','json','net','packet']
 pylibs_[json.name]=json
 
