@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 03/11/2022
+   Date last update: 07/10/2023
  */
 
 #include "vmp.h"
@@ -36,13 +36,14 @@
     Function c++ in vmp/error.h:<BR> except_s()
 */
 /*!
-    Function c++ in vmp/io.h:<BR>init(),is_debug_mode(),io_forced_unlock(),debug(),
+    Function c++ in vmp/io.h:<BR>init(),is_debug_mode(),id(),io_forced_unlock(),io_recovery_lock(),debug(),
                                  info(),warning(),error(),error_raw(),
                                  output(),output_raw(),output_file(),output_file_lines(),
                                  input(),input_file(),input_file_s(),exit_ok(),exit_failure(),copy_file(),move_file()
 */
 /*!
-    Function c++ in vmp/lib.h:<BR>system_wrap(),getpid_wrap(),getuid_wrap(),geteuid_wrap(),pause_wrap(),srand_wrap(),rand_wrap()
+    Function c++ in vmp/lib.h:<BR>system_wrap(),getpid_wrap(),getuid_wrap(),geteuid_wrap(),pause_wrap(),dup2_wrap(),
+                                  kill_wrap(),fd_noblock(),fd_block(),fd_fsync(),srand_wrap(),rand_wrap()
 */
 /*!
     Function c++ in vmp/signal.h:<BR>signum(),sigstr(),sigcmp(),signal_wrap()
@@ -76,13 +77,9 @@ void vmp_init_buf(pylib::Module module);
 void vmp_init_fs(pylib::Module module);
 
 //!Python wrapper of the c++ namespaces vampiria::vmp::thread in vmp.thread.(see c++ doc)
-/*!
-    Thread class in vmp/thread.h:<BR>Constructor Thread(pylib::Objref *)-- input arguments derived class python<BR>
-    Thread member function list:<BR>pth(),is_run(),is_self(),start(),stop(),cancel(),th_except(),run()
-*/
 /*!
     Mutex class in vmp/thread.h:<BR>Constructor Mutex()<BR>
-    Thread member function list:<BR>lock(),unlock()
+    Thread member function list:<BR>lock(),unlock(),forced_unlock(),recovery_lock()
 */
 /*!
     Blocking class in vmp/thread.h:<BR>Constructor Blocking()<BR>
@@ -92,25 +89,30 @@ void vmp_init_thread(pylib::Module module);
 
 //!Python wrapper of the c++ namespaces vampiria::vmp::time in vmp.time.(see c++ doc)
 /*!
-     Function c++ in vmp/time.h:<BR>vsleep(),time_wrap(),ctime_wrap()
+    Function c++ in vmp/time.h:<BR>vsleep(),time_wrap(),ctime_wrap(),gmtime_wrap()
 */
 /*!
-     Localtime class in vmp/time.h:<BR>Constructor Localtime(time)<BR>
-     Localtime member function list:<BR>sec(),min(),hours(),mday(),wday(),wday_n(),month(),
+    Localtime class in vmp/time.h:<BR>Constructor Localtime(time)<BR>
+    Localtime member function list:<BR>sec(),min(),hours(),mday(),wday(),wday_n(),month(),
                                         month_n(),year()
 */
 /*!
-     Timer class in vmp/time.h:<BR>Constructor Timer()<BR>
-     Timer member function list:<BR>init(),now()
+    Timer class in vmp/time.h:<BR>Constructor Timer()<BR>
+    Timer member function list:<BR>init(),now()
 */
 void vmp_init_time(pylib::Module module);
 
 //!Python wrapper of the c++ namespaces vampiria::vmp::unicode in vmp.unicode.(see c++ doc)
 /*!
-    Function c++ in vmp/unicode.h:<BR>str_split(),str_join(),str_isdigit(),str_isxdigit(),str_isreal(),
+    Function c++ in vmp/unicode.h:<BR>str_split(),str_join(),str_istype(),str_isdigit(),str_isxdigit(),str_isreal(),
     str_todigit(),str_todigit_range(),str_toreal(),str_toreal_range(),xstr_tobytes(),bytes_toxstr(),bytes_toxstr_hm()
-    str_toxstr(),xstr_tostr(),str_sub(),str_findsub(),str_replace(),str_isword(),str_format(),str_format_maxline(),str_format_end(),
-    str_extract_char(),str_remove_duplex(),str_regex
+    str_toxstr(),xstr_tostr(),str_sub(),str_findsub(),str_replace(),str_casecmp(),str_trim(),str_isword(),str_format(),
+    str_format_maxline(),str_format_end(),str_extract_char(),str_remove_duplex(),str_regex(),str_regex_matching(),
+    str_invector(),shlex_join(),shlex_join(),b64_encode(),b64_decode(),utf8_check()
+*/
+/*!
+    Strtok class in vmp/unicode.h:<BR>Constructor Strtok() or Strtok(content)<BR>
+    Strtok member funcyion list:<BR>reset(),set(),next(),get_char(),jump_chars()
 */
 void vmp_init_unicode(pylib::Module module);
 
