@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 15/05/2020
+#Date last Update : 25/01/2023
 
 from vmp_event_ import Manager as Manager
 
@@ -29,8 +29,9 @@ from vmp_event_ import inputui         as inputui
 from vmp_event_ import InputUI         as InputUI
 from vmp_event_ import simplexui       as simplexui
 from vmp_event_ import SimplexUI       as SimplexUI
-from vmp_event_ import threadui        as threadui
-from vmp_event_ import ThreadUI        as ThreadUI
 from vmp_event_ import timerui         as timerui
 from vmp_event_ import TimerUI         as TimerUI
 
+from . import process as process
+
+ 
