@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 10/05/2020
+   Date last update: 25/01/2023
  */
 
 #include "event_.h"
@@ -28,6 +28,8 @@ void event_init_manager(pylib::Module module)
     manager.def_("init",&event::Manager::init);
     manager.def_("lock",&event::Manager::lock);
     manager.def_("unlock",&event::Manager::unlock);
+    manager.def_("forced_unlock",&event::Manager::forced_unlock);
+    manager.def_("recovery_lock",&event::Manager::recovery_lock);
     manager.def_("time_now",&event::Manager::time_now);
     manager.def_("breakloop",&event::Manager::breakloop);
     manager.def_("stop",&event::Manager::stop);
@@ -156,7 +158,6 @@ void vampiria_pylib_init_module(pylib::Module init_module)
     event_init_inputui(init_module);
     event_init_timerui(init_module);
     event_init_simplexui(init_module);
-    event_init_threadui(init_module);     
+    event_init_processui(init_module);
 }
 
-
