@@ -71,7 +71,7 @@ void timer_pyevent(event::Cell *cell)
     PyTimerUI *timerui=cell->ui<PyTimerUI>();
     pylib::CArgs cargs(1);
     cargs.add<event::Cell *>(cell,false);
-    timerui->pyevent_.call(cargs);
+    pylib::PyObj res=timerui->pyevent_.call(cargs);
 }
 
 void timer_pycevent(event::Cell *cell)
@@ -79,7 +79,7 @@ void timer_pycevent(event::Cell *cell)
     PyTimerUI *timerui=cell->ui<PyTimerUI>();
     pylib::CArgs cargs(1);
     cargs.add<event::Cell *>(cell,false);
-    timerui->pycevent_.call(cargs);
+    pylib::PyObj res=timerui->pycevent_.call(cargs);
 }
 
 struct stub_TimerUI_set_event:public pylib::Member_def<PyTimerUI>
