@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 16/10/2022
+ * Date last update: 10/10/2023
  */
 
 #include "pylib.h"
@@ -93,5 +93,15 @@ void json_jtable(pylib::Module module);
 */
 void json_japi(pylib::Module module);
 
+//! Python wrapper of the c++ namespace vampiria::json::jrp in vmp_json.jrp(see c++ doc)
+/*!
+    Const c++ packet type in json/jrp.h:<BR>status_ok,status_err,status_malformed_msg,status_undef_datatype,status_accessdenied,
+                                        status_duplexsession,status_protocolbad,status_closeconnection,status_timeout,status_killed,
+                                        status_input_bad,status_input_notmanaged,status_rid_duplex<BR>
+*/
+/*!
+    function c++ in json/jrp.h:<BR>msg_status()
+*/
+void json_jrp(pylib::Module module);
 #endif
 
