@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 19/09/2022
+   Date last update: 20/06/2023
  */
 
 #include "vmp.h"
@@ -64,7 +64,7 @@ class UI
             @param cell input cell
             @return A string that identifies the cell 
         */
-        virtual vmp::str identity(event::Cell *cell)=0;
+        virtual vmp::str identity(event::Cell *cell);
         
         //!Called when an event is closed
         /*!
@@ -121,7 +121,7 @@ class Cell:public vmp::utils::Container<vmp::str>
        event::EVTCB close_;             /*!<close callback*/
        
        event::CELLRET ret_;             /*!<Exit code*/
-       vmp::str    err_;                /*!<Error info. With Exit code ERROR*/
+       vmp::str err_;                   /*!<Error info. With Exit code ERROR*/
        
        vmp::str evtype_;                /*!<Used in UI for managing multiple event types(default generic)*/
        vmp_bool writing_;               /*!<True writing associated select fd,otherwise false(default false)*/
@@ -260,6 +260,18 @@ class Manager
        //!unlock manager
        void unlock();
 
+       //! If the mutex is locked force the unlock mutual exclusion
+       /*!
+            @return 1 if unlocked otherwise 0(Used as input in recovery_lock() for recovery)
+       */
+       vmp_bool forced_unlock();
+
+       //! Recovery lock after a forced_unlock() call
+       /*!
+           @param status value returned from forced_unlock() function
+       */
+       void recovery_lock(vmp_bool status);        
+
        //!Create new Cell
        /*!
            @param ui user interface associated
