@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 15/05/2020
+   Date last update: 02/07/2023
  */
 
 #include "event.h"
@@ -63,6 +63,16 @@ void Manager::unlock()
     mutex_.unlock();
 }
 
+vmp_bool Manager::forced_unlock()
+{
+    return mutex_.forced_unlock();
+}
+
+void Manager::recovery_lock(vmp_bool status)
+{
+    mutex_.recovery_lock(status);
+}
+
 void Manager::breakloop()
 {
     if(self_ != vmp::thread::pthread_self_wrap())
@@ -190,12 +200,12 @@ void Manager::loop()
 {
     if(!init_)
         vmp::except_s("event::Manager::loop() event Manager not initialized");
-    register vmp::Select_FD select;
-    register event::Cell *cell;
-    register vmp::vector<event::Cell *> vread;
-    register vmp::vector<event::Cell *> vclose;
-    register vmp::time::Time stimeout;
-    register vmp_size s;
+    vmp::Select_FD select;
+    event::Cell *cell;
+    vmp::vector<event::Cell *> vread;
+    vmp::vector<event::Cell *> vclose;
+    vmp::time::Time stimeout;
+    vmp_size s;
     while(1)
     {
         lock();
@@ -220,10 +230,18 @@ void Manager::loop()
         }
         s=vclose.size();
         unlock();
-        for(vmp_index i=0;i < s;i++)
+        for(vmp_index i=0;i<s;i++)
         {
             cell=vclose[i];
-            cell->close_(cell);
+            try
+            {
+                cell->close_(cell);
+            }
+            catch(vmp::exception &x)
+            {
+                forced_unlock();
+                vmp::error("event::Manager::loop() close(%s) (%s)",cell->identity().c_str(),x.what());
+            }
             cell->release();
         }
         lock();
@@ -260,7 +278,17 @@ void Manager::loop()
             pcell_.push(cell);
             unlock();
             if(rbool)
-               cell->read_(cell);
+            {
+               try
+               {
+                   cell->read_(cell);
+               }
+               catch(vmp::exception &x)
+               {
+                   forced_unlock();
+                   cell->close_err(x.what());
+               }
+            }
         }
     }
     init_=false;
