@@ -37,9 +37,9 @@ void set_primitive_error(vmp::str label);
 //! JData class
 /*!
     Used for creating and reading data in json.
-    The root object is a json(object type) object that contains the fields jtype(json data type), 
-    jkey(json data key) and jbody (a json object that contains the primitives that contain the data).<BR>
-    example:{ jtype:"dataname",jkey:"ciao3",jbody:{"value":3,"str":"ciao,"extra":"extra data"}}
+    The root object is a json(object type) object that contains the fields jtype(json data type)
+    and jbody (a json object that contains the primitives that contain the data).<BR>
+    example:{ jtype:"dataname",jbody:{"value":3,"str":"ciao,"extra":"extra data"}}
 */
 class JData
 {
