@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 23/01/2020
+   Date last update: 13/01/2023
  */
 
 #include "pylib.h"
@@ -379,7 +379,6 @@ pylib::Objref *pylist_getitem(pylib::Objref *list,vmp_index pos)
     return ret;
 }
 
-
 void pylist_clear(pylib::Objref *list)
 {
     vmp_size size;
@@ -479,7 +478,7 @@ vmp_bool pydict_next(pylib::Objref *dict,Py_ssize_t *ppos,pylib::Objref **pkey,p
 void pydict_setitem(pylib::Objref *dict,pylib::Objref *key,pylib::Objref *val)
 {
     if(!pydict_check(dict))
-       vmp::except_s("pydict_setitem error input objref not dict type");
+        vmp::except_s("pydict_setitem error input objref not dict type");
     try
     {
         if(PyDict_SetItem(dict,key,val) != 0)
@@ -533,6 +532,21 @@ pylib::Objref *pycallable_call(pylib::Objref *callable,pylib::Objref *tuple)
     return ret;
 }
 
+vmp_bool gil_check()
+{
+    if(PyGILState_Check() == 0)
+        return false;
+    return true;
+}
+pylib::GilState gil_ensure()
+{
+    return PyGILState_Ensure();
+}
+
+void gil_release(GilState gstate)
+{
+    PyGILState_Release(gstate);
+}
+
 }}
 
-
