@@ -45,6 +45,12 @@ namespace vampiria { namespace vmp {
 //! string 
 typedef std::string str;
 
+//! string size type
+typedef size_t str_size;
+
+//! str_size end string
+const vmp::str_size str_npos=std::string::npos; 
+
 //!Erases  the  data  in the n bytes of the memory starting at the location pointed to by s, by writing zeroes (bytes con‐taining '\0') to that area.
 /*!
     @param s pointer memory
@@ -141,6 +147,7 @@ const vmp_uchar UCHARMAX=std::numeric_limits<vmp_uchar>::max(); /*!< Maximum lim
 
 const vmp_uint POSIX_ARG_MAX=_POSIX_ARG_MAX; /*!Arguments max length*/
 const vmp_uint RANDMAX=RAND_MAX; /*! Random generator max number*/ 
+
 }}
 
 #endif
