@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 08/12/2020
+   Date last update: 25/03/2023
  */
 
 #include "config.h"
@@ -139,6 +139,22 @@ vmp_bool module_isinstalled(vmp::str name)
     return vmp::env::software_isinstalled(mpath);
 }
 
+vmp::str pkg_path(vmp::str name,vmp::str subpath)
+{
+    vmp::str ppath=vmp::fs::union_path(VPKG,name);
+    if(!vmp::fs::isdir(ppath))
+        vmp::except("Pkg name '%s' Not Found",name.c_str());
+    return vmp::fs::union_path(ppath,subpath);
+}
+
+vmp::str vpkg_path(vmp::str name,vmp::str subpath)
+{
+    vmp::str vppath=vmp::fs::union_path(VVPKG,name);
+    if(!vmp::fs::isdir(vppath))
+        vmp::except("Vpkg name '%s' Not Found",name.c_str());
+    return vmp::fs::union_path(vppath,subpath);
+}
+
 vmp::str frm_dtd(vmp::str dtd)
 {
     vmp::str path=vmp::fs::union_path(FDTD,dtd); 
