@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 03/11/2022
+   Date last update: 24/01/2023
  */
 
 #include "vmp.h"
@@ -38,6 +38,11 @@ vmp_bool is_debug_mode()
     return debug_;
 }
 
+vmp::str id()
+{
+    return id_;
+}
+
 vmp::str va_wrap(const vmp_char *fmt,va_list ap)
 {
     vmp::str ret="";
@@ -70,9 +75,14 @@ void error_process(vmp::str type,vmp::str data)
     iomutex_.unlock();
 }
 
-void io_forced_unlock()
+vmp_bool io_forced_unlock()
 {
-    iomutex_.unlock();
+    return iomutex_.forced_unlock();
+}
+
+void io_recovery_lock(vmp_bool status)
+{
+    iomutex_.recovery_lock(status);
 }
 
 void debug_s(vmp::str msg)
