@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 03/11/2022
+   Date last update: 24/01/2023
  */
 
 #include <stdio.h>
@@ -42,6 +42,12 @@ void init(vmp::str id,vmp_bool debug=false);
 */
 vmp_bool is_debug_mode();
 
+//! Returns the process id
+/*!
+    @return process id
+*/
+vmp::str id();
+
 //!Format string value(printf style)
 /*!
     @param fmt format string
@@ -51,7 +57,16 @@ vmp_bool is_debug_mode();
 vmp::str va_wrap(const vmp_char *fmt,va_list ap);
 
 //!Forced unlock io mutex.Used in forced process interruptions,to avoid that the iomutex remains lock (signal, kill thread etc.)
-void io_forced_unlock();
+/*!
+    @return 1 if unlocked otherwise 0(Used as input in io_recovery_lock() for recovery)
+*/
+vmp_bool io_forced_unlock();
+
+//! Recovery io mutex lock after a io_forced_unlock() call
+/*!
+    @param status value returned from io_forced_unlock() function
+*/
+void io_recovery_lock(vmp_bool status);
 
 //! It writes stderr msg string if debug is setting
 /*!
@@ -177,7 +192,7 @@ void output_file_lines(vmp::str filename,vmp_bool newfile,vmp::vector<vmp::str>
 //! Reads a line on stdin                
 /*!
     @param input result of reading
-    \return the string read or the string empty if it does not read values.                
+    @return the string read or the string empty if it does not read values.                
 */                               
 vmp::str input();
 
