@@ -260,6 +260,49 @@ vmp_uint rand_wrap(vmp_uint hop)
     return ret;
 }
 
+vmp_bool istype_wrap(vmp_int c,vmp::str type)
+{
+    vmp_assert(_ISOC99_SOURCE || _POSIX_C_SOURCE >= 200112L);
+    vmp_assert(_XOPEN_SOURCE || _DEFAULT_SOURCE);
+    if((type == "alnum") && (isalnum(c) != 0))
+        return true;
+    if((type == "alpha") && (isalpha(c) != 0))
+        return true;
+    if((type == "ascii") && (isascii(c) != 0))
+        return true;
+    if((type == "blank") && (isblank(c) != 0))
+        return true;
+    if((type == "cntrl") && (iscntrl(c) != 0))
+        return true;    
+    if((type == "digit") && (c >= '0') && (c <= '9'))
+        return true;    
+    if((type == "graph") && (isgraph(c) != 0))
+        return true;
+    if((type == "lower") && (islower(c) != 0))
+        return true;
+    if((type == "print") && (isprint(c) != 0))
+        return true;
+    if((type == "punct") && (ispunct(c) != 0))
+        return true;
+    if((type == "space") && (isspace(c) != 0))
+        return true;
+    if((type == "upper") && (isupper(c) != 0))
+        return true;
+    if((type == "xdigit") && (((c >= '0') && (c <= '9')) || ((c >= 'a') && (c <= 'f')) || ((c >= 'A') && (c <= 'F'))))
+        return true;
+    return false;
+}
+
+vmp_char *strtok_r_wrap(vmp_char *str, const vmp_char *delim,vmp_char **saveptr)
+{
+    return strtok_r(str,delim,saveptr);
+}
+ 
+vmp_int strncasecmp_wrap(const vmp_char *s1, const vmp_char *s2, vmp_size n)
+{
+    return strncasecmp(s1,s2,n);
+}
+
 namespace fs {
 
 void unlink_wrap(vmp::str path)
