@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/12/2019
+   Date last update: 24/01/2023
  */
 
 #include <pthread.h>
@@ -112,11 +112,23 @@ class Mutex
         //! A destructor
         ~Mutex();
 
-        //! lock mutual exclusion
+        //! Lock mutual exclusion
         void lock();
-
-        //! unlock mutual exclusion
+        
+        //! Unlock mutual exclusion
         void unlock();
+
+        //! If the mutex is locked force the unlock mutual exclusion
+        /*!
+            @return 1 if unlocked otherwise 0(Used as input in recovery_lock() for recovery)
+        */
+        vmp_bool forced_unlock();
+
+        //! Recovery lock after a forced_unlock() call
+        /*!
+            @param status value returned from forced_unlock() function
+        */
+        void recovery_lock(vmp_bool status); 
 };
 
 //!Class Used for blocking thread
