@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/01/2020
+   Date last update: 07/10/2023
  */
 
 #include "vmp.h"
@@ -92,6 +92,24 @@ vmp::str ctime_wrap(vmp_uint time)
     return ret.substr(0,ret.size()-1);
 }
 
+vmp::str gmtime_wrap(vmp_uint time)
+{
+    vmp::str savedlocale;
+    time_t t;
+    struct tm tm;
+    vmp_char date[30];
+    savedlocale=setlocale(LC_ALL, NULL);
+    setlocale(LC_ALL,"C");
+    if (time == 0)
+        t=vmp_time();
+    else
+        t=(time_t) time;   
+    tm = *gmtime(&t);
+    strftime(date, sizeof(date),"%a, %d %b %Y %H:%M:%S %Z",&tm);
+    setlocale(LC_ALL,savedlocale.c_str());
+    return date;
+}
+
 Localtime::Localtime(vmp_uint time)
 {
     time_t t;
