@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/01/2020
+   Date last update: 10/07/2023
  */
 
 #include <time.h>
@@ -72,13 +72,20 @@ void vsleep(vmp::time::Time time);
 */
 vmp_uint time_wrap();
 
-//!Returns the current time in string format
+//!Returns the time in string format
 /*!
     @param time the number of seconds since the Epoch,1970-01-01 00:00:00 +0000 (UTC).if time=0 use present time
     @return current time string
 */
 vmp::str ctime_wrap(vmp_uint time=0);
 
+//!Returns the time in time representation, expressed in Coordinated Universal Time (UTC)
+/*!
+    @param time the number of seconds since the Epoch,1970-01-01 00:00:00 +0000 (UTC).if time=0 use present time
+    @return current gmtime string
+*/
+vmp::str gmtime_wrap(vmp_uint time=0);
+
 //!Represents local calendar time
 class Localtime
 {
