@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 27/12/2022
+   Date last update: 14/10/2023
  */
 
 #include <regex>
@@ -53,28 +53,44 @@ vmp_size str_cwrite(vmp::str *pstr,const vmp_char *fmt,...);
 */
 vmp::vector<vmp::str> str_split(vmp::str str,vmp::str delimiter);
 
-//! Creates a string concatenate strings in list, inserting the token between the strings,if delimiter=="" return charatters list
+//! Creates a string concatenate strings in list, inserting the token between the strings,if delimiter="" return charatters list
 /*!
      @param list List of strings to be concatenated
      @param token String to be inserted between the strings to be concatenated
-     @return The resulting string                        
+     @return the resulting string                        
 */
 vmp::str str_join(vmp::vector<vmp::str> list,vmp::str token);
 
-//! Check if the byte input is an integer
+//! See vmp::istype_wrap()
+/*!
+    @param byte input byte
+    @param type type of data to be checked
+    @return true if matching byte with type,otherwise false
+*/
+vmp_bool byte_istype(vmp_byte byte,vmp::str type);
+
+//! Check if the byte input is an integer(DEPRECATED)
 /*!
      @param byte input
      @return true ok,otherwise false 
 */
 vmp_bool byte_isdigit(vmp_byte byte);
 
-//! Check if the byte input is a hexadecimal integer
+//! Check if the byte input is a hexadecimal integer(DEPRECATED)
 /*!
-     @param byte input
-     @return true ok,otherwise false 
+    @param byte input
+    @return true ok,otherwise false 
 */
 vmp_bool byte_isxdigit(vmp_byte byte);
 
+//! Check if string characters are input type(see vmp::istype_wrap())
+/*!
+    @param str input string
+    @param type type of data to be checked
+    @return true if matching byte with type,otherwise false
+*/
+vmp_bool str_istype(vmp::str str,vmp::str type);
+
 //! Check if the string input is an integer
 /*!
      @param str string input
@@ -99,7 +115,7 @@ vmp_bool str_isreal(vmp::str str);
 //! Converts the string input to int
 /*!
      @param istr string input
-     @return The converted value.(except error)
+     @return The converted value or except in case of failure.
 */ 
 vmp_int str_todigit(vmp::str istr);
 
@@ -108,7 +124,7 @@ vmp_int str_todigit(vmp::str istr);
      @param istr string input
      @param min value accepted
      @param max value accepted
-     @return The converted value.(except error)
+     @return The converted value or except in case of failure.
 */ 
 vmp_int str_todigit_range(vmp::str istr,vmp_int min,vmp_int max);
 
@@ -124,14 +140,14 @@ vmp_real str_toreal(vmp::str dstr);
      @param dstr string input
      @param min value accepted
      @param max value accepted
-     @return The converted value.(except error)
+     @return The converted value or except in case of failure.
 */ 
 vmp_real str_toreal_range(vmp::str dstr,vmp_real min,vmp_real max);
 
 //! Converts a string of exadecimal values in the byte vector (2 characters 0-F 1 byte)
 /*!
      @param xstr string input
-     @return byte vector(except error)
+     @return byte vector or except in case of failure.
 */
 vmp::vector<vmp_byte> xstr_tobytes(vmp::str xstr);
 
@@ -192,6 +208,21 @@ vmp_bool str_findsub(vmp::str str,vmp::str sub);
 */
 vmp::str str_replace(vmp::str text,vmp::str find,vmp::str sub);
 
+//! Performs a byte-by-byte comparison of the strings s1 and s2, ignoring the case of the characters
+/*!
+    @param s1 input string
+    @param s2 input string
+    @return true if the comparison is verified,otherwise false
+*/
+vmp_bool str_casecmp(vmp::str str1,vmp::str str2);
+
+//!Trims a string for leading and trailing all characters with ascii code <= 0x20 or >= 0x7E.
+/* 
+    @param   str The string to trim
+    @return  The input string without leading and trailing spaces
+*/
+vmp::str str_trim(vmp::str str);
+
 //! Check if a string has ascii code characters <= 0x20 or >= 0x7E(\ n, \ t DEL SPACE etc ..)
 /*!
     @param str string input
@@ -253,6 +284,117 @@ vmp::vector<vmp::str> str_regex(vmp::str str,vmp::str str_regex,vmp_bool icase=f
 */ 
 vmp_bool str_regex_matching(vmp::str str,vmp::str str_regex);
 
+//!Check that the value of an input string is entered in the input string vector
+/*!
+    @param value input string
+    @param values vector of allowed values
+    @return true if value is in values,otherwise false
+*/
+vmp_bool str_invector(vmp::str value,vmp::vector<vmp::str> values);
+
+//!Takes a shell command in string format and splits the arguments
+/*!
+    @param args arguments in string format
+    @return split strings or except in case of failure
+*/
+vmp::vector<vmp::str> shlex_split(vmp::str args);
+
+//!Takes a shell command in vector format and returns it as a string
+/*!
+    @param vargs arguments in vector format
+    @return resulting string or except in case of failure
+*/
+vmp::str shlex_join(vmp::vector<vmp::str> vargs);
+
+//! Extract tokens from strings
+class Strtok
+{
+    private:
+        vmp::str content_;/*!<String to extract tokens*/
+        vmp_char *saveptr_;/*!<Internal usage*/
+    public:
+        //! A Constructor
+        Strtok();
+
+        //! A Constructor
+        /*!
+            @param content String to extract tokens
+        */
+        Strtok(vmp::str content);
+
+        //! A Destructor
+        ~Strtok();
+
+        //! Reset content value
+        /*!
+            @ref content_
+            @ref saveptr_
+        */
+        void reset();
+
+        //! Set content value and initialize new research
+        /*!
+            @param content String to extract tokens
+            @ref content_
+            @ref saveptr_
+        */
+        void set(vmp::str content);
+
+        //! Extract the next token from the content string
+        /*!
+            @param delim Token extraction delimiter
+            @return token string extracted
+        */
+        vmp::str next(vmp::str delim);
+
+        //! Returns the next character to read from the content or ' 0' in case there are no more characters to read
+        /*!
+            @param next char  
+        */
+        vmp_char get_char();
+
+        //! Skip n characters in sequence
+        /*!
+            @param n number of characters to skip
+        */
+        void jump_chars(vmp_index n);
+};
+
+/**
+ * Base64 index table.Interna usage
+*/
+static const char b64_table[] = {
+  'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H',
+  'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P',
+  'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X',
+  'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f',
+  'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n',
+  'o', 'p', 'q', 'r', 's', 't', 'u', 'v',
+  'w', 'x', 'y', 'z', '0', '1', '2', '3',
+  '4', '5', '6', '7', '8', '9', '+', '/'
+};
+
+//! Encoding a string in base 64
+/*!
+    @param src input string
+    @return string encoded in base 64
+*/
+vmp::str b64_encode(vmp::str src);
+
+//! Decoding a base 64 string
+/*!
+    @param enc oncoding 64 string
+    @return decoded string or except in case of failure
+*/
+vmp::str b64_decode(vmp::str enc);
+
+//! Check if a string is in utf8 format
+/*!
+    @param src input string
+    @return true if src string is in utf8 format,otherwise false
+*/
+vmp_bool utf8_check(vmp::str src);
+
 }}}
 
 #endif
