@@ -24,7 +24,6 @@ import vmp_gui0 as gui
 import vmp_net as net
 
 import config      as cfg
-#import gvmp_utils  as utils
 import gvmp_pycode as pycode
 
 class GenericTag(xml.Tag):
@@ -635,7 +634,26 @@ class TreeTag(xml.Tag):
         for i in range(0,nc):
           c=self.get_child(i)
           c.parse(tag,var)
-          
+ 
+class ArgsTag(TreeTag):
+  def __init__(self):
+    TreeTag.__init__(self)
+    
+  def parse(self,ptag,var):
+    if self.if_check(var):
+      text=self.get_text()
+      if text != "":
+        vtext=pycode.new_data_type(text)
+        if pycode.data_isstatic(vtext):
+          tag=self.add_tag_text(ptag,text)
+          self.add_attrs(tag,var)
+        else:
+          data=pycode.data_dict_value(vtext,var)
+          for d in data:
+            tag=self.add_tag_text(ptag,d)
+            self.add_attrs(tag,var)
+            break 
+         
 def parse(filepath,mask):
   parser=xml.Parser()
   parser.add_tag("gvampiria",GenericTag)
@@ -671,6 +689,8 @@ def parse(filepath,mask):
   parser.add_tag("input",TreeTag)
   parser.add_tag("par",TreeTag)
   parser.add_tag("var",TreeTag)
+  parser.add_tag("software",TreeTag)
+  parser.add_tag("args",ArgsTag)
   parser.add_tag("stderr",TreeTag)
   parser.add_tag("stdout",TreeTag)
   parser.add_tag("fileout",TreeTag)
